# pyaidoop-dl-models
aidoop-dl-models python package module

## Setup
### setup commands
```
pip install -r requirements.txt
pip install --upgrade pip
pip install twine
python setup.py install
python setup.py sdist bdist_wheel
python -m twine upload dist/*
```